[Zope-Checkins] CVS: Zope/inst/skel/inst/skel/bin - ntservice.py:1.1.2.3

Chris McDonough chrism@zope.com
Mon, 13 Jan 2003 12:15:28 -0500


Update of /cvs-repository/Zope/inst/skel/inst/skel/bin
In directory cvs.zope.org:/tmp/cvs-serv3443/inst/skel/inst/skel/bin

Modified Files:
      Tag: chrism-install-branch
	ntservice.py 
Log Message:
Renamed "zctl" to "zopectl" (as per TODO).


=== Zope/inst/skel/inst/skel/bin/ntservice.py 1.1.2.2 => 1.1.2.3 ===
--- Zope/inst/skel/inst/skel/bin/ntservice.py:1.1.2.2	Wed Oct  9 11:37:09 2002
+++ Zope/inst/skel/inst/skel/bin/ntservice.py	Mon Jan 13 12:14:56 2003
@@ -16,16 +16,16 @@
 Zope instance home in which it's installed.
 
 """
-import zctl
+import zopectl
 from Controller.NTService import NTService
 import win32serviceutil
 import win32api
 import os, sys
 
 # assumes zctl is in bin dir of instance home
 dn = os.path.dirname
 
-instance = os.path.abspath(dn(dn(zctl.__file__)))
+instance = os.path.abspath(dn(dn(zopectl.__file__)))
 
 servicename = os.path.splitdrive(instance)[1]
 servicename = servicename.replace("\\", '_')
@@ -67,10 +67,10 @@
     win32serviceutil.HandleCommandLine(InstanceService)
     if 'install' in sys.argv:
         python = win32api.GetShortPathName(sys.executable)
-        zctl = zctl.__file__
-        if zctl[-3:] in ('pyc', 'pyo'):
-            zctl = zctl[:-1]
-        cmd = win32api.GetShortPathName(zctl)
+        zopectl = zopectl.__file__
+        if zopectl[-3:] in ('pyc', 'pyo'):
+            zopectl = zopectl[:-1]
+        cmd = win32api.GetShortPathName(zopectl)
         start_command="%s %s start" % (python, cmd)
         stop_command ="%s %s stop" % (python, cmd)
         set_start_command(start_command)
@@ -16,16 +16,16 @@
 import os, sys
 
-# assumes zctl is in bin dir of instance home
+# assumes zopectl is in bin dir of instance home
 dn = os.path.dirname
 